to_bytes

Function to_bytes 

pub(crate) const fn to_bytes(nbits: u32) -> usize
Calculate a usize representing the number of bytes required to store the given number of bits represented as a u32 (i.e. rounding up).