to_limbs

Function to_limbs 

pub(crate) const fn to_limbs(nbits: u32) -> usize
Calculate a usize representing the number of limbs required to store the given number of bits represented as a u32 (i.e. rounding up).